==> boo-0.7.8.2559-src.zip: src/Boo.Lang.Compiler/Pipelines/ResolveExpressions.cs <==
#region license
// Copyright (c) 2004, Rodrigo B. de Oliveira (rbo@acm.org)
// All rights reserved.
// 
// Redistribution and use in source and binary forms, with or without modification,
// are permitted provided that the following conditions are met:
// 
//     * Redistributions of source code must retain the above copyright notice,
//     this list of conditions and the following disclaimer.
//     * Redistributions in binary form must reproduce the above copyright notice,
//     this list of conditions and the following disclaimer in the documentation
//     and/or other materials provided with the distribution.
//     * Neither the name of Rodrigo B. de Oliveira nor the names of its
//     contributors may be used to endorse or promote products derived from this
//     software without specific prior written permission.
// 
// THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" AND
// ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
// WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
// DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT OWNER OR CONTRIBUTORS BE LIABLE
// FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
// DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR
// SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER
// CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
// OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF
// THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
#endregion

namespace Boo.Lang.Compiler.Pipelines
{
	using Boo.Lang.Compiler.Steps;
	
	public class ResolveExpressions : Parse 
	{
		public ResolveExpressions()
		{
			Add(new InitializeTypeSystemServices());
			Add(new PreErrorChecking());
			
			Add(new MergePartialClasses());
			
			Add(new InitializeNameResolutionService());
			Add(new IntroduceGlobalNamespaces());
			Add(new TransformCallableDefinitions());
			Add(new BindTypeDefinitions());			
			Add(new BindNamespaces());
			Add(new BindBaseTypes());
			Add(new BindAndApplyAttributes());
			
			Add(new ExpandMacros());
			Add(new IntroduceModuleClasses());
			Add(new NormalizeStatementModifiers());
			Add(new NormalizeTypeAndMemberDefinitions());
			
			Add(new BindTypeDefinitions());
			Add(new BindEnumMembers());
			Add(new BindBaseTypes());

			Add(new ResolveTypeReferences());
			
			Add(new BindTypeMembers());
			
			Add(new ProcessInheritedAbstractMembers());
			Add(new CheckMemberNames());
			
			Add(new ExpandAstLiterals());
			Add(new ProcessMethodBodiesWithDuckTyping());
			
			Add(new PreProcessExtensionMethods());
		}
	}
}

==> boo-0.9.1.3287-src.zip: src/Boo.Lang.Compiler/Pipelines/ResolveExpressions.cs <==
#region license
// Copyright (c) 2004, Rodrigo B. de Oliveira (rbo@acm.org)
// All rights reserved.
// 
// Redistribution and use in source and binary forms, with or without modification,
// are permitted provided that the following conditions are met:
// 
//     * Redistributions of source code must retain the above copyright notice,
//     this list of conditions and the following disclaimer.
//     * Redistributions in binary form must reproduce the above copyright notice,
//     this list of conditions and the following disclaimer in the documentation
//     and/or other materials provided with the distribution.
//     * Neither the name of Rodrigo B. de Oliveira nor the names of its
//     contributors may be used to endorse or promote products derived from this
//     software without specific prior written permission.
// 
// THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" AND
// ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
// WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
// DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT OWNER OR CONTRIBUTORS BE LIABLE
// FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
// DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR
// SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER
// CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
// OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF
// THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
#endregion

namespace Boo.Lang.Compiler.Pipelines
{
	using Boo.Lang.Compiler.Steps;
	
	public class ResolveExpressions : ExpandMacros 
	{
		public ResolveExpressions()
		{
			Add(new ExpandAstLiterals());
			
			Add(new IntroduceModuleClasses());
			Add(new NormalizeStatementModifiers());
			Add(new NormalizeTypeAndMemberDefinitions());
			Add(new NormalizeOmittedExpressions());

			Add(new BindTypeDefinitions());
			Add(new BindGenericParameters());
			Add(new BindEnumMembers());
			Add(new BindBaseTypes());

			Add(new BindMethods());
			Add(new ResolveTypeReferences());
			Add(new BindTypeMembers());
			Add(new CheckGenericConstraints());
			
			Add(new ProcessInheritedAbstractMembers());
			Add(new CheckMemberNames());
			
			Add(new ProcessMethodBodiesWithDuckTyping());
			
			Add(new PreProcessExtensionMethods());
		}
	}
}
